@@ -2,7 +2,7 @@
 
 
 package HiD;
-$HiD::VERSION = '1.93'; # TRIAL
+$HiD::VERSION = '1.94'; # TRIAL
 use Moose;
 use namespace::autoclean;
 # note: we also do 'with HiD::Role::DoesLogging', just later on because reasons.
@@ -20,7 +20,7 @@ use DateTime;
 use File::Find::Rule;
 use Path::Tiny;
 use Try::Tiny;
-use YAML::XS           qw/ LoadFile /;
+use YAML::Tiny;
 
 use HiD::File;
 use HiD::Layout;
@@ -75,7 +75,7 @@ sub _build_config {
 
   if ( my $file = $self->config_file ) {
     try {
-      $config = LoadFile( $file ) // {};
+      $config = YAML::Tiny->read( $file )->[0] // {};
       ref $config eq 'HASH' or die $!;
       $config_loaded++;
     };
@@ -675,7 +675,7 @@ sub publish {
 
     my $path = path( $file->output_filename );
     while ( $path ne '.' ) {
-      $self->add_written_file( $path->stringify => 1 );
+      $self->add_written_file( $path->stringify() => 1 );
       $path = $path->parent;
     }
   }
@@ -986,7 +986,7 @@ L<StaticVolt>
 
 =head1 VERSION
 
-version 1.93
+version 1.94
 
 =head1 AUTHOR
 
