@@ -2,7 +2,7 @@
 
 
 package HiD::App::Command::init;
-$HiD::App::Command::init::VERSION = '1.93'; # TRIAL
+$HiD::App::Command::init::VERSION = '1.94'; # TRIAL
 use Moose;
 extends 'HiD::App::Command';
 use namespace::autoclean;
@@ -14,7 +14,7 @@ use warnings    qw/ FATAL  utf8     /;
 use open        qw/ :std  :utf8     /;
 use charnames   qw/ :full           /;
 
-use YAML::XS qw/ DumpFile /;
+use YAML::Tiny;
 
 
 has blog => (
@@ -61,9 +61,8 @@ EOF
 
   $self->_init_blog if $self->blog;
 
-  DumpFile( '_config.yml' , {
-    title => $self->title ,
-  });
+  my $yaml = YAML::Tiny->new({ title => $self->title });
+  $yaml->write( '_config.yml' );
 
   say "Enjoy your new site!";
 }
@@ -148,7 +147,7 @@ sub commands.
 
 =head1 VERSION
 
-version 1.93
+version 1.94
 
 =head1 AUTHOR
 
