@@ -2,7 +2,7 @@
 
 
 package HiD::Page;
-$HiD::Page::VERSION = '1.93'; # TRIAL
+$HiD::Page::VERSION = '1.94'; # TRIAL
 use Moose;
 with 'HiD::Role::IsConverted';
 with 'HiD::Role::IsPublished';
@@ -39,10 +39,12 @@ sub _build_url {
   my $format = $self->get_metadata( 'permalink' ) // 'none';
 
   my $source = $self->source;
+
   my $path_frag = $self->input_path;
   $path_frag =~ s/^$source//;
+  $path_frag ||= Path::Tiny->rootdir();
 
-  my $naive = join '/' , $path_frag , $self->basename;
+  my $naive = path( $path_frag , $self->basename() );
 
   my %_valid_exts = map { $_=>1 } qw(rss xml html htm xhtml xhtm shtml shtm);
   my $ext = exists $_valid_exts{$self->ext} ? $self->ext : 'html';
@@ -105,7 +107,7 @@ object from this class works.
 
 =head1 VERSION
 
-version 1.93
+version 1.94
 
 =head1 AUTHOR
 
