@@ -1,13 +1,12 @@
+package Test::HiD::File;
 use strict;
 use warnings;
 
-package Test::HiD::File;
 use Test::Routine;
 use Test::More;
 use Test::File;
 use namespace::autoclean;
 
-use File::Temp qw/ tempfile tempdir /;
 use HiD::File;
 
 has subject => (
@@ -16,16 +15,16 @@ has subject => (
 );
 
 test "output filename" => sub {
-  my $test = shift;
+  my $test    = shift;
   my $subject = $test->subject;
 
   my $input  = $subject->input_filename;
   my $output = $subject->output_filename;
-  like( $output , qr/$input$/ , 'output ends like input');
+  like( $output , qr/\Q$input\E$/ , 'output ends like input');
 };
 
 test "publish" => sub {
-  my $test = shift;
+  my $test    = shift;
   my $subject = $test->subject;
 
   my $output = $subject->output_filename;
